% This script is used to compare the rotor thrust coefficient obtained
% with the low fidelity model and with the high-fidelity simulations in
% PowerFLOW. Figure 2.5 of the dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data files
%High-fidelity
load ../data/HIGHFIDELITY.mat
%AC model with Delphine formulation Ncrit = 0.01
load ../data/AC_N0p01.mat
%AC model with Delphine formulation Ncrit = 7
load ../data/AC_N7.mat
%AC model with Delphine formulation Ncrit = 9
load ../data/AC_N9.mat
%% Organise data for plotting
%CT AC model stored to get a line in the plot
CT_AC_N0p01 = [AC_N0p01.CT AC_N0p01.CT AC_N0p01.CT AC_N0p01.CT AC_N0p01.CT]; 
CT_AC_N7 = [AC_N7.CT AC_N7.CT AC_N7.CT AC_N7.CT AC_N7.CT]; 
CT_AC_N9 = [AC_N9.CT AC_N9.CT AC_N9.CT AC_N9.CT AC_N9.CT]; 
%Number of voxels stored to get the xaxis of the plot
total_voxels = [0 HIGHFIDELITY.n_voxels_coarse HIGHFIDELITY.n_voxels_medium HIGHFIDELITY.n_voxels_fine HIGHFIDELITY.n_voxels_last];
%% Plots
cd('../plot')
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
hold on; grid on;
p11 = plot(HIGHFIDELITY.n_voxels_coarse,HIGHFIDELITY.CT_coarse,'-s','Color',mycolor.cyan_thesis,'LineWidth',3,'MarkerSize',15,'MarkerFaceColor',mycolor.cyan_thesis);
p12 = plot(HIGHFIDELITY.n_voxels_medium,HIGHFIDELITY.CT_medium,'->','Color',mycolor.cyan_thesis,'LineWidth',3,'MarkerSize',15,'MarkerFaceColor',mycolor.cyan_thesis);
p13 = plot(HIGHFIDELITY.n_voxels_fine,HIGHFIDELITY.CT_fine,'-*','Color',mycolor.cyan_thesis,'LineWidth',3,'MarkerSize',15,'MarkerFaceColor',mycolor.cyan_thesis);
plot([HIGHFIDELITY.n_voxels_coarse HIGHFIDELITY.n_voxels_medium HIGHFIDELITY.n_voxels_fine],[HIGHFIDELITY.CT_coarse HIGHFIDELITY.CT_medium HIGHFIDELITY.CT_fine],'-','Color',mycolor.cyan_thesis,'LineWidth',3,'MarkerSize',20);
p2 = plot(total_voxels,CT_AC_N0p01,'Color',mycolor.grey,'LineWidth',3);
p3 = plot(total_voxels,CT_AC_N7,'Color',mycolor.lightred,'LineWidth',3);
p4 = plot(total_voxels,CT_AC_N9,'--','Color',mycolor.black,'LineWidth',3);
xlim([1*10^7 7*10^7])
ylim([0.4 1])
xlabel('$N$[-]','interpreter','latex','FontWeight','bold');
ylabel('$C_T$ [-]','interpreter','latex','FontWeight','bold');
lg = legend([p11 p12 p13 p2 p3 p4],'LB-VLES coarse','LB-VLES medium','LB-VLES fine',...
    'AC model Ncrit = 0.01','AC model Ncrit = 7','AC model Ncrit = 9');
set(lg,'Interpreter','latex','Location','southeast','Numcolumns',2)
set(gca,'TickLabelInterpreter','latex','FontSize',28,'FontWeight','bold')
exportgraphics(hfig,'CT_vs_voxels_new_V5.pdf');
saveas(hfig,'CT_vs_voxels_new_V5','fig');
