function [CL_final, CD_final] = Dynamicstall_V2(alpha,time,chord,U,POLAR,N,state)

time = time;

%% Input
a = 343;     % speed of sound [m/s]
Niter = 10;   % iterations

%% Define cylcic blade pitching oscillations
dt = (time(2)-time(1));    % time step
ds = U.*dt/(chord/2); % semichords travelled in each time step

% Pitch rate at 3/4 chord
pitchrate = [0 (alpha(2:end)-alpha(1:end-1))/dt];

%% Repeat for Niter cycles
alpha = repmat(alpha,1,Niter);
time = repmat(time,1,Niter);
pitchrate = repmat(pitchrate,1,Niter);
U  = repmat(U,1,Niter);
ds  = repmat(ds,1,Niter);

%% Constants
A1 = 0.3;
A2 = 0.7;
b1 = 0.14;
b2 = 0.53;

eta = 0.97; % recovery factor
Ka = 0.75;

Tp = 1.7;  % peak pressure - cn lag
Tf = 3.0;  % boundary layer - peak pressure lag
Tv = 6.0;  % vortex decay constant
Tvl = 11.0; % trailing edge position, in semichords

%% Polar
alpha_st = deg2rad([POLAR(state).alpha]);
CL_st = [POLAR(state).CL] ;
CD_st = [POLAR(state).CD];
CN_st = CL_st.*cos(alpha_st)+CD_st.*sin(alpha_st);
CC_st = CL_st.*sin(alpha_st)-CD_st.*cos(alpha_st);

[arange] = [find(abs(alpha_st-deg2rad(-5)) == min(abs(alpha_st-deg2rad(-5)))): find(abs(alpha_st-deg2rad(5)) == min(abs(alpha_st-deg2rad(5))))];
[Alpha_0] = interp1(CL_st(arange),alpha_st(arange),0,'linear','extrap');
CL0 = interp1(alpha_st(arange),CL_st(arange),0,'linear','extrap');
CLa = max((CL_st(arange)-CL0)./(alpha_st(arange)));
CD0 = interp1(alpha_st(arange),CD_st(arange),0,'linear','extrap');

CN0 = interp1(alpha_st(arange),CN_st(arange),0,'linear','extrap');
CC0 = interp1(alpha_st(arange),CC_st(arange),0,'linear','extrap');
CNa = max((CN_st(arange)-CN0)./(alpha_st(arange)));

f_st = (2.*sqrt(CN_st./(CNa*(alpha_st-Alpha_0)))-1).^2; % separation point location
f_st(isinf(f_st)) = 1;
f_st(isnan(f_st)) = 1;


%% Initialise variables variables
init = 0.0;
dalpha = init*ones(1,length(time));
X = init*ones(1,length(time));
Y = init*ones(1,length(time));
Z = init*ones(1,length(time));
alpha_E = init*ones(1,length(time));
D = init*ones(1,length(time));
CN_C = init*ones(1,length(time));
CD_C = init*ones(1,length(time));
R_alpha = init*ones(1,length(time));
R_Iprime = init*ones(1,length(time));
CN_I = init*ones(1,length(time));
R_q = init*ones(1,length(time));
R_qprime = init*ones(1,length(time));
CN_q = init*ones(1,length(time));
CL_attached = init*ones(1,length(time));
CD_attached = init*ones(1,length(time));
CN_attached = init*ones(1,length(time));
CC_attached = init*ones(1,length(time));
Dp = init*ones(1,length(time));
CN_prime = init*ones(1,length(time));
alpha_p = init*ones(1,length(time));
f_p = init*ones(1,length(time));
Df = init*ones(1,length(time));
f_prime = init*ones(1,length(time));
CN_separated = init*ones(1,length(time));
CC_separated = init*ones(1,length(time));
tau_v = init*ones(1,length(time));
Vx = init*ones(1,length(time));
df = init*ones(1,length(time));
fl_doubleprime = init*ones(1,length(time));
CN_vortex = init*ones(1,length(time));
CC_vortex = init*ones(1,length(time));
r =  init*ones(1,length(time)); 
alpha_cr = init*ones(1,length(time)); 
KN = init*ones(1,length(time));
CV = init*ones(1,length(time));
CN = init*ones(1,length(time));
CC = init*ones(1,length(time));
CL = init*ones(1,length(time));
CD = init*ones(1,length(time));

%% Dynamic model
for n = 2:length(time)
    dalpha(n) = alpha(n)-alpha(n-1);
      
% Module 1 -  Attached flow: Circulatory terms, impulsive terms due to  
% angle of attack and pitch rate 
    % Circulatory
    X(n) = X(n-1)*exp(-b1*ds(n))+A1*dalpha(n)*exp(-b1*ds(n)/2);
    Y(n) = Y(n-1)*exp(-b2*ds(n))+A2*dalpha(n)*exp(-b2*ds(n)/2);
    alpha_E(n) =  alpha(n)-X(n)-Y(n);
    CN_C(n) = CNa*(alpha_E(n)-Alpha_0); 

    % Impulsive
    D(n) = D(n-1)*exp(-dt/(Ka*chord/a))+(dalpha(n)-dalpha(n-1))/dt*exp(-dt/(2*Ka*chord/a));
    CN_I(n) = 3*chord/U(n)*(dalpha(n)/dt-D(n));
       
    % Forces in attached flow 
    CN_attached(n) = CN_C(n)+CN_I(n);
    CC_attached(n) = CNa*(alpha_E(n)-Alpha_0)^2; 

% Module 2 - Separated flow: leading and trailing edge pressure response
    % Leading edge pressure response
    Dp(n) = Dp(n-1)*exp(-ds(n)/Tp)+(CN_attached(n)-CN_attached(n-1))*exp(-ds(n)/(2*Tp));
    CN_prime(n) = CN_attached(n)-Dp(n);
    alpha_p(n) = (CN_prime(n)-CN0)/CNa;
    f_p(n) = interp1(alpha_st,f_st,alpha_p(n),'linear','extrap');

    % Trailing edge pressure response
    Df(n) = Df(n-1)*exp(-ds(n)/Tf)+(f_p(n)-f_p(n-1))*exp(-ds(n)/(2*Tf));
    f_prime(n) = f_p(n)-Df(n);
    
    % Forces in separated flow
    CN_separated(n) = CN_attached(n)*((1+sqrt(f_prime(n)))/2)^2;
    %%% BRUCE: CN_separated(n) = CNa*alpha_E(n) *((1+sqrt(f_prime(n)))/2)^2+CN_I(n);
    CC_separated(n) = eta*CNa*(alpha_E(n)-Alpha_0)^2*sqrt(f_prime(n));
    
% Module 3 - Vortex shedding
    % Criteria for dynamic stall vortex shedding
    Cn1 = 1.5;
  
    % Time variable   
    if abs(CN_prime(n))>Cn1  %alpha_p(n)>alpha_cr(n) && dalpha(n)>0
        tau_v(n) = tau_v(n-1)+dt/(chord)*U(n)*0.45;
    else
        tau_v(n) = 0;
    end
    
    % Vortex normal force coefficient  
    KN(n) = (1+sqrt(f_prime(n)))^2/4;
    CV(n) = CN_attached(n)*(1-KN(n)); 
    %%% BRUCE: CV(n) = CN_C(n)*(1-KN(n)); 
    
    % Accumulated vortex normal force due to leading edge separation
    if (tau_v(n) < Tvl) && (CV(n)-CV(n-1))>0
        CN_vortex(n) = CN_vortex(n-1)*exp(-ds(n)/Tv)+(CV(n)-CV(n-1))*exp(-ds(n)/(2*Tv));
    else
        CN_vortex(n) = CN_vortex(n-1)*exp(-ds(n)/Tv);
    end 
    
% Module 4 - Final force
    CN(n) = CN_vortex(n)+CN_separated(n);
    CC(n) = CC_separated(n)+CC0;
    CL(n) = CN(n)*cos(alpha(n))+CC(n)*sin(alpha(n));
    CD(n) = CN(n)*sin(alpha(n))-CC(n)*cos(alpha(n));
    
end

figure(101)
subplot(1,2,1)
    plot(alpha(end-N:end)*180/pi,CL(end-N:end))
    hold on
    plot(POLAR(state).alpha,POLAR(state).CL)
subplot(1,2,2)
    plot(alpha(end-N:end)*180/pi,CD(end-N:end))
    hold on
    plot(POLAR(state).alpha,POLAR(state).CD)

%% Select results of last iteration

CL_final = CL(end-N+1:end);
CD_final = CD(end-N+1:end);


