    
%%Run Actuator Cylinder Model

blade.twistangle = deg2rad(blade.twistangle);     % Twist angle [rad]
blade.pitch = deg2rad(blade.pitch);        % Pitch angle [rad]
blade.tsr=(blade.speed.*blade.radius)./blade.meanflow; %Tip speed ratio
R = blade.radius;
 
% Additional parameters
% N = blade.ts/blade.sampling;
N = 36;
Ngrid = 16;                 % Number of cells in grid [-]
f = 1.001;                  % Factor for evaluation points [-]
tol = 1e-7;                 % Tolerance for while loop [-]
relax = 0.1;                % Relaxation paramter [-]

flowfield = 'On';

%Define control points
% Discretise control points
dtheta = 10*pi/180;
theta = 0*pi/180:10*pi/180:350*pi/180;
% dtheta = 2*pi/N;
% theta = (1:N)*dtheta-1/2*dtheta;
xc = -R*sin(theta);
yc = R*cos(theta);

% Discretise evaluation points
xe = f*xc/R;   %streamwise direction
ye = f*yc/R;   %lateral direction

%% Influence matrix
% Prelocation
Rwx = zeros(N,N);   %Influence coefficient for induction in stream wise direction
Rwy = zeros(N,N);   %Inlfuence coefficient for induction in lateral direction

for i=1:N           % Influence of control points
    for j=1:N       % On evaluation points
        theta_int = linspace((theta(i)-0.5*dtheta),(theta(i)+0.5*dtheta),1000);
        Rx_int = (-(xe(j)+sin(theta_int)).*sin(theta_int)+(ye(j)-cos(theta_int)).*cos(theta_int))./((xe(j)+sin(theta_int)).^2+(ye(j)-cos(theta_int)).^2);
        Ry_int = (-(xe(j)+sin(theta_int)).*cos(theta_int)-(ye(j)-cos(theta_int)).*sin(theta_int))./((xe(j)+sin(theta_int)).^2+(ye(j)-cos(theta_int)).^2);
        
        %integrate along the azimuth
        Rwx(i,j) = -trapz(theta_int,Rx_int);
        Rwy(i,j) = -trapz(theta_int,Ry_int);
    end
end

%% Compute induced velocities

% Preallocate
wx = zeros(1,N);     %Induced velocity in stream wise direction
wy = zeros(1,N);     %Induced velocity in lateral direction
wxold = ones(1,N);
wyold = ones(1,N);
wx_i = zeros(N,N);
wy_i = zeros(N,N);

itera = 0;

while (abs(wx-wxold)>tol) | (abs(wy-wyold)>tol)
    clear Cl
    clear Cd
    clear alpha_deg
    % Initialise
    itera = itera+1;
    wxold = wx;
    wyold = wy;
    
    %Remember that the velocity components are vx = 1+wx and vy = wy.
    % Calculate velocities
    Vx = blade.meanflow+blade.speed*R.*cos(theta)+blade.meanflow.*wx;    % X-direction, same as the wind speed
    Vy = blade.speed*R.*sin(theta)+blade.meanflow.*wy;                   % Y-direction, pointing north
    Vt = Vx.*cos(theta)+Vy.*sin(theta);                                  % Tangential, from leading to trailing edge
    Vn = Vx.*sin(theta)-Vy.*cos(theta);                                  % Radial, pointing inwards
    Vrel = sqrt(Vx.^2+Vy.^2);                                            % Relative velocity
    
    % Calculate angle of attack
    phi = atan(Vn./Vt);                        % Flow angle [rad]
    alpha = phi-blade.pitch-blade.twistangle;  % Angle of attack [rad]
    alpha_deg = rad2deg(alpha);                % Angle of attack [degree]
        
    % Airfoil lift and drag(linear relation)
%     [Cl, Cd] = liftdrag_Delphine(alpha);
    
    %Calculate Reynolds number
    Re = (blade.chord*Vrel)/blade.nu;                          %Reynolds number [-]
    
%     Check if polars for the current Reynolds are available
    eval(['Re_max_stored = max(cell2mat(aerodata.airfoil.Re));']);
    eval(['Re_min_stored = min(cell2mat(aerodata.airfoil.Re));']);
    
    if Re > Re_max_stored
            error('================================================================== \nRe = is too high. \nIt is necessary to calculate the the polars for higher Reynolds. \n==================================================================\R\n')
    elseif Re < Re_min_stored
            error('================================================================== \nRe = is too low. \nIt is necessary to calculate the the polars for lower Reynolds. \n==================================================================\R\n')
    end

    for i = 1:length(alpha_deg)
     eval(['Cl_sect(i)= Cl_fun(alpha_deg(i), Re(i));']);
     eval(['Cd_sect(i)= Cd_fun(alpha_deg(i), Re(i));']);   
    end
    

       Cl = Cl_sect;
       Cd = Cd_sect;

%Interpolate Cl and Cd from the Bruce polars (dynamic stall is included)
% for i = 1:length(alpha_deg)
%     if alpha_deg(i) <= -8
%         [Cl,Cd] = liftdrag_Delphine(alpha);
%     elseif alpha_deg(i) >= 11
%          [Cl,Cd] = liftdrag_Delphine(alpha);
%     else
%      eval(['Cl(i)= Cl_fun(alpha_deg(i));']);
%      eval(['Cd(i)= Cd_fun(alpha_deg(i));']);   
% end
%  
% end 
   
   
   
   % Blade loading
    Cn = Cl.*cos(alpha)+Cd.*sin(alpha);
    Ct = Cl.*sin(alpha)-Cd.*cos(alpha);
    
    Lift = 0.5*blade.rho*Vrel.^2*blade.chord.*Cl;            % Lift
    Drag = 0.5*blade.rho*Vrel.^2*blade.chord.*Cd;            % Drag
    Faxial = Lift.*cos(phi) + Drag.*sin(phi);                % Axial force
    Fazimuth = Lift.*sin(phi) - Drag.*cos(phi);              % Azimuthal force
    
    Fn = 0.5*blade.rho*Vrel.^2*blade.chord.*Cn;              % Normal, pointing outwards
    Ft = 0.5*blade.rho*Vrel.^2*blade.chord.*Ct;              % Tangential, from trailing to leading edge

    Qn = blade.n*(Fn.*cos(blade.pitch)-Ft.*sin(blade.pitch))./(2*pi*R*blade.rho*blade.meanflow^2);  %reaction of the blade forces
    Qt = -blade.n*(Ft.*cos(blade.pitch)+Fn.*sin(blade.pitch))./(2*pi*R*blade.rho*blade.meanflow^2); %reaction of the blade forces
    

   % Influence of control point(i) on other locations(j)
    wx = 1/(2*pi)*Qn*Rwx+1/(2*pi)*Qt*Rwy;
    wy = 1/(2*pi)*Qn*Rwy-1/(2*pi)*Qt*Rwx;
    
    % Add effect of cylinder
    if f >= 1                            % In the wake
        for j = N/2+1:N
            wx(j) = wx(j)+Qn(j)-Qn(N+1-j);
        end    
    elseif f < 1                        % Inside the cylinder
        for j = 1:N/2
            wx(j) = wx(j)-Qn(j);
        end
        for j = N/2+1:N
            wx(j) = wx(j)-Qn(N+1-j);
        end
    end
    
    % Mod-Lin model (Modified linear solution)
    CT = dtheta*sum(Qn.*sin(theta) + Qt.*cos(theta));
    
    %%% method 1
    a = 0.0892074.*CT.^3 +0.0544955.* CT.^2 + 0.251163.*CT -0.0017077;
    
    ka = 1/(1-a);

     wxnew = ka.*wx;
     wynew = ka.*wy;
     
     % Relaxation
      wx = ((1-relax).*wxold+relax.*wxnew);
      wy = ((1-relax).*wyold+relax.*wynew);
     
    if itera>200
        warning('More than 200 iterations, code is stopped')
        break
    end
end



%% Power coefficient
Cp_ideal=trapz(theta,Qn.*Vn./(blade.meanflow)); 
Cp_real=1/(2*pi)*trapz(theta,blade.n.*((Ft.*cos(blade.pitch)+Fn.*sin(blade.pitch)).*blade.speed.*R))/(0.5*blade.rho*blade.meanflow^3*2*R);

Cp_local = -Qt.*blade.tsr;
Cp = (sum(Cp_local*dtheta))

CT = dtheta*sum(Qn.*sin(theta) + Qt.*cos(theta))
CT2 = trapz(theta,Qn.*sin(theta)+Qt.*cos(theta));

Thrust = 0.5*blade.rho*blade.meanflow.^2*CT*blade.span*1.5;
Power = 0.5*blade.rho*blade.meanflow.^3*Cp*blade.span*1.5;
Total_thrust = 0.5*blade.rho*blade.meanflow.^2*CT*blade.span*1.5*2;  %mean thrust
Total_power = 0.5*blade.rho*blade.meanflow.^3*Cp*blade.span*1.5*2;

%% Save values in structures

Aerodynamics.Cl = Cl;
Aerodynamics.Cd = Cd;
Aerodynamics.Cp = Cp;
Aerodynamics.CT = CT;
Aerodynamics.Thrust = Thrust;
Aerodynamics.Power = Power;
Aerodynamics.totalthrust = Total_thrust;
Aerodynamics.totalpower = Total_power;



blade.Vrel = Vrel;
blade.aoa = alpha_deg;
blade.Re = Re;
blade.theta = theta;