function [tno] = BL_TNO_Xfoil(bl,W1,Re,c3,count)

%this function calculates the aero parameters needed to solve the TNO method
%using flat plate theory.

%% 1) determine the boundary layer velocity profile, U1
% Extract the value of delta for the pressure side and for the suction
% side, according to what is specified in the function.
tno.delta=bl.delta(count);

%Line normal to the trailing edge of the airfoil, used later.
tno.x2=linspace(0.0001,tno.delta,400);

%U0, freestream velocity.
U0=W1;

%Skin friction coefficient
Cf = bl.Cf(count);
%u*, u_star, velocity [m/s]
u_star=U0.*sqrt(Cf/2);

%Uw, W, wake velocity [m/s]
W=1-cos(pi.*tno.x2./tno.delta);

%kinematic viscosity at sealevel [m2/s]
v_1=1.343*10^-5; 

%von Karman constant [-]
k_1=0.41;

%Constant [-]
B=5.5;

%Boundary layer velocity profile U1
tno.U1=u_star.*(log(u_star.*tno.x2./v_1)./k_1+B+W.*(U0./u_star-log(u_star.*tno.delta./v_1)./k_1-B)./2); %eq 19, Lee

%% 2) Determine the transverse integral length scale, Lt_2

%Mixing length lm
%First with Prandtl hyphotesis
lm=0.085.*tno.delta.*tanh(k_1.*tno.x2./(0.085.*tno.delta));

%Second Klebanoff damping function
mod2=0.2;
lm(ceil(length(tno.x2)*mod2:end))=lm(ceil(length(tno.x2)*mod2:end))./sqrt(1+(B*(tno.x2(ceil(length(tno.x2)*mod2:end))./tno.delta).^6));

%Transverse integral length scale, Lt_2, L2
tno.L2=lm./k_1;
% prova = mean(tno.L2);
% LT{count} = prova;
% save(['prova_' num2str(count) '_' num2str(c3) '.mat'],'prova')
%% 3) Determine the turbulent kinetic energy, kt, and the turbulent shear stress U22.

%Turbulent viscosity v_t to compute the kinetic energy in the boundary
%layer
v_t=lm.^2.*abs(gradient(tno.U1,abs(tno.x2(1)-tno.x2(2))));

%Turbulent kinetic energy tke
tno.tke=sqrt(v_t.^2.*gradient(tno.U1,abs(tno.x2(1)-tno.x2(2))).^2./0.09);

%Turbulent shear stress
%c3 can be used both for symmetric airfoil at zero angle of attack (i.e.
%0.45) and for non-symmetric airfoil (i.e. 0.3 on the pressure side and
%0.45 on the suction side)
tno.u22=c3.*tno.tke;

end

