function [BL, probe] = BL_Xfoil(blade,n_aero,xtr_u,xtr_l,iter,Re)

mkdir Section_data_AC_DELPHINE_N7;
mkdir Section_data_AC_DELPHINE_N7/BL;
mkdir Section_data_AC_DELPHINE_N7/Xtr;

for i = 1:length(blade.theta)
    file_bl = strcat('Section_data_AC_DELPHINE_N7/BL/Section_theta', num2str(blade.theta(i)), '.txt');     
    file_xtr = strcat('Section_data_AC_DELPHINE_N7/Xtr/Section_theta', num2str(blade.theta(i)), '.txt');
    
    % Round Re for Xfoil convergence
    digit = numel(num2str(round(Re(i))));
    re = round(Re(i)/10^(digit-2))*10^(digit-2);
    
    % Input file for Xfoil
    fileID = fopen('InputBL_xfoil.dat', 'w');
    if  blade.airfoil == 'blade_optydb'
           name_bruce_polar = 'blade_optydb.dat';
           fprintf(fileID, 'load %s\r\n',name_bruce_polar);
    else
        fprintf(fileID, '%s\r\n',blade.airfoil);
    end
   fprintf(fileID, 'ppar\r\n');
    fprintf(fileID, 'n\r\n');
    fprintf(fileID, '%i\r\n', 2*n_aero);
    fprintf(fileID, '\r\n');
    fprintf(fileID, '\r\n');
    fprintf(fileID, 'pane\r\n');
    fprintf(fileID, 'oper\r\n');
    fprintf(fileID, 'iter\r\n');
    fprintf(fileID, '%i\r\n', iter);
    fprintf(fileID, 'v %i\r\n', Re(i));
    fprintf(fileID, 'vpar\r\n');
    fprintf(fileID, 'xtr %1.2f %1.2f\r\n', xtr_u, xtr_l);
    fprintf(fileID, '\r\n');
    fprintf(fileID, 'a %.2f\r\n', blade.aoa(i));
%     fprintf(fileID, 'cpwr %s\r\n', file_cp);
    fprintf(fileID, 'dump %s\r\n', file_bl);
    fprintf(fileID, 'p\r\n');
    fprintf(fileID, '%s\r\n', file_xtr);
    fprintf(fileID, '\r\n');
    fprintf(fileID, 'a %.2f\r\n', blade.aoa(i));
    fprintf(fileID, 'p\r\n');
    fprintf(fileID, '\r\n');
    fprintf(fileID,'quit');
    fclose(fileID);
    
    % Run Xfoil
    if isunix
        system('xfoil < InputBL_xfoil.dat > Output_BL.dat');
    elseif ispc
        local = pwd;
        command = strcat('cd',32,local,32,'&& xfoil.exe < InputBL_xfoil.dat > Output_BL.dat');
        system(command);
    end
end
files_bl = dir('Section_data_AC_DELPHINE_N0p01/BL/*.txt');

names_bl = {files_bl.name};


N = length(files_bl);

for i = 1:N
    name_bl = char(names_bl(:,i));
    path = strcat('Section_data_AC_DELPHINE_N7/BL/', name_bl);

    fileID = fopen(path);
    if isunix
        data = textscan(fileID, '%f %f %f %f %f %f %f %f %f %f %f %f', n_aero, 'headerlines', 1);
        data = [data{1} data{2} data{3} data{4} data{5} data{6} data{7} data{8} data{9} data{10} data{11} data{12}];
        eval(['BL.Section' num2str(i) '{1} = data(:,2);']);    % x position
        eval(['BL.Section' num2str(i) '{2} = data(:,3);']);    % y position
        eval(['BL.Section' num2str(i) '{3} = data(:,4);']);    % Ue/Vinf
        eval(['BL.Section' num2str(i) '{4} = data(:,5);']);    % Dstar
        eval(['BL.Section' num2str(i) '{5} = data(:,6);']);    % blade.theta
        eval(['BL.Section' num2str(i) '{6} = data(:,7);']);    % Cf
        eval(['BL.Section' num2str(i) '{7} = data(:,8);']);    % H
    elseif ispc
        data = textscan(fileID, '%f %f %f %f %f %f %f %f', n_aero, 'headerlines', 1);
        data = [data{1} data{2} data{3} data{4} data{5} data{6} data{7} data{8}];
        eval(['BL.Section' num2str(i) '{1} = data(:,2);']);    % x position
        eval(['BL.Section' num2str(i) '{2} = data(:,3);']);    % y position
        eval(['BL.Section' num2str(i) '{3} = data(:,4);']);    % Ue/Vinf
        eval(['BL.Section' num2str(i) '{4} = data(:,5);']);    % Dstar
        eval(['BL.Section' num2str(i) '{5} = data(:,6);']);    % blade.theta
        eval(['BL.Section' num2str(i) '{6} = data(:,7);']);    % Cf
        eval(['BL.Section' num2str(i) '{7} = data(:,8);']);    % H
    end
    clear data;
    fclose(fileID);
end

for i = 1:N
    % Ue TE
    eval(['Ue_Vinf_u(' num2str(i) ') = BL.Section' num2str(i) '{3}(1);']);  
    Ue_u(i) = Ue_Vinf_u(i)*blade.Vrel(i);
    eval(['Ue_Vinf_l(' num2str(i) ') = BL.Section' num2str(i) '{3}(end);']);
    Ue_l(i) = Ue_Vinf_l(i)*blade.Vrel(i);
    
    % Dstrar TE
    eval(['dstar_u(' num2str(i) ') = BL.Section' num2str(i) '{4}(1);']);
    dstar_u(i) = dstar_u(i)*blade.chord; 
    eval(['dstar_l(' num2str(i) ') = BL.Section' num2str(i) '{4}(end);']);
    dstar_l(i) = dstar_l(i)*blade.chord;
    
    % blade.theta TE
    eval(['theta_u(' num2str(i) ') = BL.Section' num2str(i) '{5}(1);']);
    theta_u(i) = theta_u(i)*blade.chord;
    eval(['theta_l(' num2str(i) ') = BL.Section' num2str(i) '{5}(end);']);
    theta_l(i) = theta_l(i)*blade.chord;
    
    % Tau wall
    eval(['cf_u(' num2str(i) ') = BL.Section' num2str(i) '{6}(1);']);
    tau_u(i) = cf_u(i)*0.5*blade.rho*blade.Vrel(i)^2;
    eval(['cf_l(' num2str(i) ') = BL.Section' num2str(i) '{6}(end);'])
    tau_l(i) = cf_l(i)*0.5*blade.rho*blade.Vrel(i)^2;
    
    % H TE
    eval(['H_u(' num2str(i) ') = BL.Section' num2str(i) '{7}(1);']);
    eval(['H_l(' num2str(i) ') = BL.Section' num2str(i) '{7}(end);']);
    
    % Delta TE
    H1_u = 3.15 + 1.72/(H_u(i)-1) - 0.01*(H_u(i)-1)^2;
    delta_u(i) = H1_u*theta_u(i) + dstar_u(i);

    H1_l = 3.15 + 1.72/(H_l(i)-1) - 0.01*(H_l(i)-1)^2;
    delta_l(i) = H1_l*theta_l(i) + dstar_l(i);
  
%     % dp/dx TE
%     qinf = 0.5*blade.rho*blade.Vrel(i)^2;
%     eval(['x_cut_u = CP.Section' num2str(i) '{1}(1:end/2);']);
%     eval(['cp_cut_u = CP.Section' num2str(i) '{2}(1:end/2);']);
%     [m, index] = min(abs(x_cut_u - 0.95));
%     dx_u(i) = (x_cut_u(index) - x_cut_u(index + 1));
%     dp_dx_u(i) = (cp_cut_u(index) - cp_cut_u(index + 1))*qinf/dx_u(i);
%     
%     eval(['x_cut_l = CP.Section' num2str(i) '{1}(end/2:end);']);
%     eval(['cp_cut_l = CP.Section' num2str(i) '{2}(end/2:end);']);
%     [m, index] = min(abs(x_cut_l - 0.95));
%     dx_l(i) = (x_cut_l(index) - x_cut_l(index - 1));
%     dp_dx_l(i) = (cp_cut_l(index) - cp_cut_l(index - 1))*qinf/dx_l(i);
    
end
%Organize the value in the structure probe
probe.pressure.delta = delta_l;
probe.pressure.delta_star = dstar_l;
probe.pressure.thet_1 = theta_l;
probe.pressure.Hl = H1_l;
% probe.pressure.Hk H_l;
probe.pressure.Cf = cf_l;
probe.pressure.tau = tau_l;

probe.suction.delta = delta_u;
probe.suction.delta_star = dstar_u;
probe.suction.thet_1 = theta_u;
probe.suction.Hl = H1_u;
% probe.suction.Hk H_u;
probe.suction.Cf = cf_u;
probe.suction.tau = tau_u;

% delete InputBL_xfoil.dat
% if isunix
%     %system('rm -rf Section_data');
% end