 function  SPL=LBLnoise_BPM_Xfoil(alpha,L,c,U,f,DH,r)
%  function  SPL=LBLnoise_BPM_Xfoil(alpha,L,c,U,f,DH,r,delta_p)
 
%The code calculates the laminar boundary layer-vortex shedding (LBL-VS) noise.
%The approach explained in Brooks,Pope and Marcolini is followed.

% U: flow speed relative to the blade
% c: chord length
% L: segment length
% alpha: angle of attack /degrees
% f : frequency /Hz
% tripped : tripping boolean 

% Generally uses the notation in report NREL/TP-500-34478
c0=342.943;       %sound speed [m/s]
rho=1.20615;      %density [kg/m3]
nu=1.50142e-5;     %kinematic viscosity [m2/s]


M=U/c0;        %Mach number [-] where U is the blade velocity [m/s]
Re=U.*c/nu;    %chord Reynolds number where c is the chord length of the blade [m]


%Compute delta_p according to BPM formulation
 if Re <= 0.3*10^6
        delta_0=c.*10.^(1.892-0.9045*log10(Re)+0.0596*(log10(Re).^2));
    else
        
        delta_0=c.*10.^(1.892-0.9045*log10(Re)+0.0596*(log10(Re).^2));
 end

%Compute the boundary layer thickness for the pressure side

   delta_p=delta_0.*10.^(-0.04175*alpha+0.00106*alpha.^2);

   
    

%Strouhal definitions

%St_prime

St_prime=(f.*delta_p)./U;


% St1_prime 

if Re <= 1.3*10^5
    St1_prime = 0.18;
elseif (Re > 1.3*10^5) && (Re <= 4.0*10^5)
    St1_prime = 0.001756*Re.^(0.3931);
else
    St1_prime = 0.28;
end

% St_ppeak

St_ppeak = St1_prime.*10.^(-0.04.*alpha);


SPL=10*log10((delta_p.*M.^5*L.*DH)/r^2)+G1(St_prime,St_ppeak)+G2(Re,alpha)+G3(alpha);

%According to Pearson for the experiments where the TSR was held constant
%while the tunnel speed was varied, the blades angle of attack should have
%been the same for all cases so the function G3 could be ignored.
% SPL=10*log10((delta_p.*M.^5*L.*DH)/r^2)+G1(St_prime,St_ppeak)+G2(Re,alpha);
 
  
end