function  SPL=TEnoise_BPM_Xfoil(alpha,L,c,U,f,DH,r)
% function  SPL=TEnoise_BPM_Xfoil(alpha,L,c,U,f,DH,r,deltastar_p,deltastar_s)
   
%The code calculates the TE-blutness noise.
%The approach explained in Brooks,Pope and Marcolini is followed.

% U: flow speed relative to the blade
% c: chord length
% L: segment length
% alpha: angle of attack /degrees
% f : frequency /Hz
% tripped : tripping boolean 

% Generally uses the notation in report NREL/TP-500-34478
c0=342.943;       %sound speed [m/s]
rho=1.20615;      %density [kg/m3]
nu=1.50142e-5;     %kinematic viscosity [m2/s]


M=U/c0;        %Mach number [-] where U is the blade velocity [m/s]
Re=U.*c/nu;    %chord Reynolds number where c is the chord length of the blade [m]

%Degree of blutness, h (m)
h = 0.0011;

%solid angle,phi(degree)
phi = 14;
phi0=0;

if Re <= 0.3*10^6
        delta_0=c.*10.^(1.892-0.9045*log10(Re)+0.0596*(log10(Re).^2));
        deltastar_0=c.*0.0601.*Re^-0.114;
else
        delta_0=c.*10.^(1.892-0.9045*log10(Re)+0.0596*(log10(Re).^2));
        deltastar_0=c*10.^(3.411-1.5397*log10(Re)+0.1059*(log10(Re).^2));
end

%Compute the boundary layer thickness for the pressure side
    deltastar_p=deltastar_0.*10.^(-0.0432*alpha+0.00113*alpha.^2);
   
    
%Compute the boundary layer thickness for the suction side

if 0 <= alpha || alpha <= 5
    
    deltastar_s = delta_0.*10.^(0.0679*alpha);   
elseif 5 < alpha || alpha <= 12.5
    deltastar_s = delta_0.*0.381*10.^(0.1516*alpha);
else
    deltastar_s = deltastar_0.*14.296.*10.^(0.0258.*alpha);
    
    
end


%Average boundary layer displacement thickness, delta_avg
delta_avg = (deltastar_p + deltastar_s)/2;

%Strouhal definitions

%St_third
St_third=(f.*h)./U;


% St_third_peak 
if h/delta_avg >= 0.2 
    St_third_peak = (0.212 - 0.0045*phi)/(1+0.235*(h/delta_avg)^(-1) - 0.0132*(h/delta_avg)^(-2));
else
    St_third_peak = 0.1.*(h/delta_avg)+0.095-0.00243*phi;
end



SPL=10*log10((h*M.^5.5*L.*DH)/r^2)+G4(h,delta_avg,phi)+G5(h,delta_avg,phi,phi0,St_third,St_third_peak);

  end
