% This code read the AC model data and produce noise estimations for a VAWT.

clear all
close all 
clc

tic %start timer

%% 0 Choose if you want to have a single microphone or multiple
p = 2;  %if p = 1 horizontal configuration, if p = 2 vertical configuration
        %if p = 0 single microphone (coordinates specified in
        %initalise_var). Use single microphone if you need to calculate the
        %boundary layer parameters with Xfoil.
mic = MICS(p);

%% 1 Initialise model
% Use function initialise_var for uploading turbine geometry and for output
for ind = 1:length(mic)
    clearvars -except mic ind noise_1
    [blade,file]=initialise_var(mic,ind);

    cd(file.dir1); %install directory


%% 2 Choose between microphones and single observer

Observer();

%% 3 Load the output from the AC model feed it with experimental data and high-fidelity data
load ../data/AC_N7.mat

blade.Vrel = AC_N7.Vrel;
blade.aoa = AC_N7.alpha;
blade.Re =(blade.chord*blade.Vrel)/blade.nu; %Reynolds number [-]                         
blade.theta = AC_N7.theta;

%% 4 Boundary Layer Integral Parameters
n_aero = 80;
iter = 200;

if blade.BL == 1
    disp(['Running Xfoil to compute BL parameters']);
    [BL, probe] = BL_Xfoil(blade,n_aero,blade.xtr_u,blade.xtr_l,iter,blade.Re);
else
    [BL,probe] = read_BL_Xfoil(blade,n_aero);
end


%% 6 Noise code

countobservers=0;

for observers=direc_loop          %1:length(ob_x)
    if file.plot_dir==1           %if we want to plot directivity check these
        disp(['current observer:' num2str(observers) '/' num2str(length(obs_x))]);
        countobservers=countobservers+1;
        
        blade.observer(1)=obs_x(observers);
        blade.observer(2)=obs_y(observers);
        blade.observer(3)=obs_z(observers);
        
    end
    countsim=0;
    
    for vel_loop=1:length(blade.meanflow) %for us it is only a set of velocity
        countsource=0;
        % countsim=countsim+1;
        
        for sources1=(blade.sources) %loop for blade discretisation (max inf)
            countsource=countsource+1;
            blade.num_sources=blade.sources(countsource);
            counttimestep=0;
            
            for timestep1=1:length(blade.sampling) %loop for time step (max is ~of ts per rotation for CFD)
                countsim=countsim+1;
                
                disp(['current sim:' num2str(countsim) '/' num2str(length(blade.sampling)*length(blade.sources)*length(blade.meanflow))]);
                counttimestep=counttimestep+1;
                blade.timestep_size=1./(blade.sampling(counttimestep)/100);
                
                if countsim==1 %save workspace for first ever loop
                    disp('INITIAL SAVE')
                    file.dont_clear=[who];
                    file.blade=blade;
                end
                file.blade.num_sources=blade.num_sources;
                file.blade.timestep_size=blade.timestep_size;
                file.blade.observer=blade.observer;
                
%                 derive various values required for predictions
                derived_initialisation();
                count=0;
                fprintf(['calculation point: ' num2str(blade.discretisation)]);
                 for ii=1:(blade.discretisation)% -1) %outer loop for timesteps

                    fprintf([' ' num2str(blade.discretisation-ii)]);
                    count=count+1;
                    
                    %% Blade Coordinates
                    %ii is the timestep being evaluated 
                    %the actual timestep can be calculated knowing ii and the total
                    %number of timesteps per revolution.
                    
                    [blade]=bladeCoord_Xfoil(blade,ii,count,AC_N7.theta); %all blade coords along span for one angle. 
                    %blade coords here for later visualisation
                    data(ii).azimuth = blade.azimuth1;
                    %X,Y,Z represent the 3D-coordinates of the trailing
                    %edge
                    X((count-1)*sources1+1:(count-1)*sources1+sources1)=blade.te.x;
                    Y((count-1)*sources1+1:(count-1)*sources1+sources1)=blade.te.y;
                    Z((count-1)*sources1+1:(count-1)*sources1+sources1)=blade.te.z;
                    
                    %Plot the blade sources
%                     fig10 = figure(10);
%                     plot3(Z,X,Y,'-r');
%                     grid on
%                     xlabel('z [m]','interpreter','latex','FontSize',30,'FontWeight','bold');
%                     ylabel('x [m]','interpreter','latex','FontSize',30,'FontWeight','bold');
%                     zlabel('y [m]','interpreter','latex','FontSize',30,'FontWeight','bold');
%                     set(gca,'FontSize',28,'TickLabelInterpreter','latex');
                    
                    count2=0;
                    
                    for ij=1:blade.num_sources %inner loop for blade discretisation

   
                        fprintf(['  sc: ' num2str(blade.num_sources-ij)]);
                        count2=count2+1;
                        
                        %% Define flow parameters (BPM and TNO models)
                        
                
                          flow_params_Xfoil;
                          
                        
                        %% Noise modelling
                        
                        [blade,noise]= noiseCalc_Xfoil(blade,count,noise,f,ij,probe,sources1);
                        
                                            
                    end
                 end
                  %find total noise
                
                       noise=weightedSPL(noise,blade,f,ASPL,file,vel_loop);
            end
        end
    end
%     plot_directivity()
end
toc                   
%% 7 Plot results
% results_Xfoil();

%Save files
noise_1{ind} = noise;

end