function [blade]=attenuation(blade,ij,f)

%calculate attenuation factors from blades based on two angles.
%FIGURE ON MY NOTE!!!
%loop through number of y 'point sources' (ij)

%vectors defined as per figure B3 Brooks et al for new CS.
%attenuation is based on the angle from the TE to the observer

%define a vector from the te to the observer
v3= [(blade.observer(3)-blade.te.z(ij)) (blade.observer(1)-blade.te.x(ij)) (blade.observer(2)-blade.te.y(ij))];
v3_unit=v3./norm(v3);

%v1 y is constant.
%z1 should go to ground or else the chord lengths messed up

%convert location to polar to add angle changes for other blade positions
[thet_te,r_te]=cart2pol(blade.te.z(ij)-blade.centre.z,blade.te.x(ij)-blade.centre.x);
rot_angle=blade.rotations(1)-blade.rotations(2); 
[v1z, v1x]=pol2cart(thet_te,r_te);

if ij==1 %start
    v1y=(blade.te.y(ij+1)-blade.te.y(ij));
elseif ij==blade.num_sources %end
    v1y=(blade.te.y(ij)-blade.te.y(ij-1));
else %middle
    v1y=(blade.te.y(ij+1)-blade.te.y(ij-1));
end

%add centre back
y_e= [v1z-blade.te.z(ij)+blade.centre.z v1x-blade.te.x(ij)+blade.centre.x v1y];

%vector along blade length
%basic y_e assuming straight blade:
y_e_unit=y_e./norm(y_e);

%unit vector x_e, along the chord of the blade
x_e_temp=[blade.te.z(ij)-blade.le.z(ij) blade.te.x(ij)-blade.le.x(ij) blade.te.y(ij)-blade.le.y(ij)];
x_e_unit=x_e_temp./norm(x_e_temp);

%find the angle from vector relations
%A.B=|A||B|cos(theta)
%theta_e is the angle between x1 and the distance between the trailing edge
%and the observer or the angle between xe (along chord length) and the
%distance between the trailing edge and the observer(v3).
theta_e=acos((dot(x_e_unit,v3_unit))/(norm(x_e_unit)*norm(v3_unit)));

% unit vector of inflow velocity
Wv_unit=[blade.Wv/norm(blade.Wv) 0];
%eta_e is defined as the angle from the blade chord inflow velocity to the
%line running from the source to the observer, essentially it phi_e
%corrected for blade angle of attack.
eta_e=acos((dot(Wv_unit,v3_unit))/(norm(Wv_unit)*norm(v3_unit)));

%find true size of x_e based on trig |v2|/|v3|=cos(thet)
x_e=(cos(theta_e).*norm(v3)).*x_e_unit;

%------------- new 20 may
z_e=cross(x_e,y_e);
z_e_unit=z_e./norm(z_e);
% 
% figure
% quiver3(0,0,0,(x_e(1)),x_e(2),x_e(3)) 
% hold on
% quiver3(0,0,0,(y_e(1)),y_e(2),y_e(3))
% quiver3(0,0,0,(z_e(1)),z_e(2),z_e(3))
% axis equal

%proj of v3 on z_e
% angle between:
ang1=acos((dot(z_e_unit,v3_unit))/(norm(z_e_unit)*norm(y_e_unit)));
proj_v3_ze=norm(v3)*cos(ang1);

%proj of v3 on y_e
ang1=acos((dot(y_e_unit,v3_unit))/(norm(z_e_unit)*norm(y_e_unit)));
proj_v3_ye=norm(v3)*cos(ang1);

%assuming xe,ze are 90 degrees apart
psi_e=atan(proj_v3_ze/proj_v3_ye);
%--------------

v2=[blade.observer(3)-(blade.te.z(ij)+x_e(3)) blade.observer(1)-(blade.te.x(ij)+x_e(1)) blade.observer(2)-(blade.te.y(ij)+x_e(2))];
v2_unit=v2./norm(v2);


%directivity from buck: http://www.sciencedirect.com/science/article/pii/S0022460X16304564
dir_vel=blade.M;

%this is for TE directivity
blade.directivityL=(sin(theta_e).^2.*sin(psi_e).^2)./(1-dir_vel.*cos(eta_e)).^4;
blade.directivityH=2*(sin(theta_e/2)).^2.*sin(psi_e).^2./(1-dir_vel.*cos(eta_e)).^4;

%Since inflow-turbulence noise is radiated from the leading edge and not
%from the trailing edge theta_e substitute with pi-theta_e
%content.
%for LE directivity flip things around...
blade.directivityL_TI=(sin(pi-theta_e).^2.*sin(psi_e).^2)./(1-dir_vel.*cos(eta_e)).^4;


% 
%  figure(32132132)
%  hold on
%  scatter(blade.currentangle,theta_e,'k')
% % scatter(blade.currentangle,psi_e,'g')
% % scatter(blade.currentangle,eta_e,'r')


%% plot functions
% if blade.attenuationPlot==1
%     
% 
%     % some test plots
%     disp(num2str(eta_e))
%     disp(num2str(theta_e))
%     figure(7987)
%     scatter(blade.currentangle,blade.directivityL,'xk')
%     hold on
%     set(gcf,'color','white')
%     set(gca, 'FontName', 'L M Roman10', 'FontSize', 12)
%     box off
%     title('Directivity Comparisons - L')
%     axis([0 2*pi 0 2])
%     axis square
%     
%     ylabel('Directivity')
%     xlabel('Azimuthal Angle')
%     figure(7988)
%     scatter(blade.currentangle,blade.directivityH,'xk')
%     hold on
%     %scatter(blade.currentangle,blade.directivityH2,'k')
%     % scatter(probe.suction.u_0,probe.suction.delta);
%     set(gcf,'color','white')
%     set(gca, 'FontName', 'L M Roman10', 'FontSize', 12)
%     box off
%     title('Directivity Comparisons - H')
%     axis([0 2*pi 0 2])
%     axis square
%     
%     ylabel('Directivity')
%     xlabel('Azimuthal Angle')
%     
    %% 3d visualisaton
    
    
%     figure(7)
%     scatter3(blade.le.x(ij),blade.le.y(ij),blade.le.z(ij),'filled')
%     hold on
%     
%     scatter3(blade.te.x(ij),blade.te.y(ij),blade.te.z(ij))
%     scatter3(blade.observer(1),blade.observer(2),blade.observer(3),'filled')
%     
%     plot3([blade.te.x(end)+x_e(1) blade.te.x(end)],[ blade.te.y(end)+x_e(2) blade.te.y(end)], [blade.te.z(end)+x_e(3) blade.te.z(end)])
%     
%     plot3([blade.te.x(end)+x_e(1) blade.observer(1)],[blade.te.y(end)+x_e(2) blade.observer(2)], [blade.te.z(end)+x_e(3) blade.observer(3)])
%     
%     plot3([blade.te.x(end) blade.observer(1)],[blade.te.y(end) blade.observer(2)], [blade.te.z(end) blade.observer(3)])
%     
%     plot3([blade.te.x(end)+x_e(1) blade.te.x(end)+x_e(1)-y_e_unit(1)],[ blade.te.y(end)+x_e(2)  blade.te.y(end)+x_e(2)-y_e_unit(2)], [blade.te.z(end)+x_e(3) blade.te.z(end)+x_e(3)-y_e_unit(3)])
%     
%     plot3([blade.te.x(ij)+x_e(1) blade.te.x(ij)],[ blade.te.y(ij)+x_e(2) blade.te.y(ij)], [blade.te.z(ij)+x_e(3) blade.te.z(ij)])
%     
%     plot3([blade.te.x(ij)+x_e(1) blade.observer(1)],[blade.te.y(ij)+x_e(2) blade.observer(2)], [blade.te.z(ij)+x_e(3) blade.observer(3)])
%     
%     plot3([blade.te.x(ij) blade.observer(1)],[blade.te.y(ij) blade.observer(2)], [blade.te.z(ij) blade.observer(3)])
%     
%     plot3([blade.te.x(ij)+x_e(1) blade.te.x(ij)+x_e(1)-y_e(1)],[ blade.te.y(ij)+x_e(2)  blade.te.y(ij)+x_e(2)-y_e(2)], [blade.te.z(ij)+x_e(3) blade.te.z(ij)+x_e(3)-y_e(3)])
%     
%     plot3([blade.te.x(ij) blade.te.x(ij)+y_e(1)],[ blade.te.y(ij)  blade.te.y(ij)+y_e(2)], [blade.te.z(ij) blade.te.z(ij)+y_e(3)])
%     
    
end




