function [blade] = bladeCoord_Xfoil(blade,ii,count,theta)

% This function gives the coordinates of a VAWT at one specific time step (ii)
%use cylindrical coordinates r and theta to define the rotations

% Get the blade coordinates  at each theta (time step)
% (positve y aligns along with turbine axis)

%% Y-coord for leading edge and trailing edge.

%Determine blade azimuth for each of the equidistant calculation points
%defined in derived_initialisation (blade.discretisation =
%timestep/sampling_percentage). It is expressed in radians.
blade.azimuth1=theta(ii);



%incremental division spacing
blade.ddiv=blade.span/blade.num_sources;

%the number of sources along the blade are along y-axis.
%determine the y-coord of the leading edge. y varies while x and z are
%constants.
blade.le.y=zeros(blade.num_sources)';
blade.le.y=blade.ddiv/2:blade.ddiv:blade.span;



blade.te.y=blade.le.y; 

%blade.rotations gives the angle of each blade along y.
blade.rotations=((blade.offsetangle.*pi/180)/blade.span).*blade.le.y; %radians

%% X and Z-coords for leading edge and trailing edge.

%To calculate the TE coords, determine the distance of the TE from the
%center of the airfoil.
b2=(blade.chord/2-blade.offset);

%Determine the polar coordinates of the trailing edge. After the
%conversion, they corresponds to X and Z cartesian coords.
pitch.r=b2;

pitch.theta=blade.pitch;

%convert pitch.theta in radians (multiply by pi/180)
[te.z,te.x]=pol2cart(pitch.theta*pi/180,pitch.r);
te.x=te.x+blade.radius;

%extend to LE
le.z=te.z-blade.chord*cosd(blade.pitch);
le.x=te.x+blade.chord*sind(blade.pitch);

%apply transformation of the angle that the blade currently resides at.
%add centre CS here
[le.theta,le.r]=cart2pol(le.z,le.x);
[te.theta,te.r]=cart2pol(te.z,te.x);

blade.le.theta=le.theta+blade.azimuth1+blade.rotations-pi;%radians
blade.te.theta=te.theta+blade.azimuth1+blade.rotations-pi;%radians


%x1,z1 is where I want the position to be
[blade.le.z1,blade.le.x1]=pol2cart(blade.le.theta,le.r);
[blade.te.z1,blade.te.x1]=pol2cart(blade.te.theta,te.r);


blade.le.x=blade.le.x1;
blade.le.y=blade.le.y;
blade.le.z=blade.le.z1;
blade.te.x=blade.te.x1;
blade.te.y=blade.te.y;
blade.te.z=blade.te.z1;



%% Plot

%     fig99=figure(99);  
%     scatter3(blade.te.z1,blade.te.x1,blade.te.y,'k','filled')
%     hold on
%     scatter3(blade.le.z1,blade.le.x1,blade.le.y,'r','filled')
%     ciao = num2str(ii);
%     ciao2 = cellstr(ciao);
%     dx = 0.001;
%     text(blade.te.z +dx,blade.te.x +dx, blade.te.y + dx, ciao2);
%     text(blade.le.z +dx,blade.le.x +dx, blade.le.y + dx, ciao2);
%     xlabel('z [m]','interpreter','latex','FontSize',30,'FontWeight','bold')
%     ylabel('x [m]','interpreter','latex','FontSize',30,'FontWeight','bold')
%     zlabel('y [m]','interpreter','latex','FontSize',30,'FontWeight','bold')
%     lg = legend('Trailing Edge','Leading Edge');
%     set(lg,'Interpreter','latex');
%     set(gca,'Ydir','reverse');
%     set(gca,'Xdir','reverse');
%     set(gca,'FontSize',28,'TickLabelInterpreter','latex');

end
