%% Determine the Doppler correction factor
% The Doppler correction factor is called blade.dop

%velocity vector
chord_vec=[blade.te.z1(ij)-blade.le.z1(ij) +blade.te.x1(ij)-blade.le.x1(ij)];
chord_vec_u=[chord_vec./norm(chord_vec) 0];
vel_vec=blade.W.*chord_vec_u;

%projection of velocity along chord vector
re=[(blade.observer(3)-blade.te.z1(ij)) (blade.observer(1)-blade.te.x1(ij)) (blade.observer(2)-blade.te.y(ij))];

%z corresponds to the local inflow velocity at the blade inlet
z=vel_vec;
%x corresponds to the difference between the coordinates of the observer
%and the trailing edge of the blade (look at figure in my note)
x=re;

% receiver-location
ang_1= 2 * atan(norm(z*norm(x) - norm(z)*x) / norm(z * norm(x) + norm(z) * x));
%https://www.mathworks.com/matlabcentral/answers/16243-angle-between-two-vectors-in-3d
%[EDITED]: W. Kahan suggested in his paper "Mindeless.pdf":

%Doppler correction (blade.dop) gives the relationship between the observed
%frequency,f, and the emitted frequency, f0. blade.c0 is the sound speed.

%u_receiver is the velocity of the receiver relative to the medium [m/s],
%positive if the receiver is moving towards the source (and negative in the
%other direction). For the case in this analysis U receiver is zero as the
%observer is always considered to be stationary.
u_receiver = 0;

%vs is the velocity of the source relative to the medium, positive if the
%source is moving away from the receiver (and negative in the other
%direction).
vs=blade.W.*cos(ang_1);

blade.dop(ii,ij)=(blade.c0+u_receiver)./(blade.c0+vs);


