 function [blade,file]=initialise_var(mic,ind)


%% Name of the case

file.case='PitchVAWT_V2';

%% Blade Object

%geometry
blade.span=1.5; % span length [m].
blade.n=2; % number of blades [-].
blade.chord=0.075; % chord length [m].
blade.pitch=0; %positive is clockwise [degree].
blade.twistangle = 0; % twist angle [degree].
blade.radius=0.75;  % blade radius [m].
blade.sigma = 0.1;  % solidity [-].
blade.airfoil = 'blade_optydb'; %profile type [-]
blade.tripped=1; %using tripped/untripped model for CFD calc. Equal to 1 activate the tripped BL.

%Free transition
blade.xtr_u = 1;            % BL transition point (x/c) for the suction surface.
blade.xtr_l = 1;            % BL transition point (x/c) for the pressure surface.

%Forced transition with the trip both on the suction side and on the
%pressure side.
% blade.xtr_u = 0.15;            % BL transition point (x/c) for the suction surface.
% blade.xtr_l = 0.15;            % BL transition point (x/c) for the pressure surface.
% blade.xtr_u = 0.5;            % BL transition point (x/c) for the suction surface.
% blade.xtr_l = 0.5;            % BL transition point (x/c) for the pressure surface.
% blade.xtr_u = 0.05;             % BL transition point (x/c) for the suction surface. (AC_DELPHINE_N7)
% blade.xtr_l = 0.05;             % BL transition point (x/c) for the pressure surface. (AC_DELPHINE_N7)
% coordinates of the turbine center
blade.centre.x=0;  
blade.centre.y=0;
blade.centre.z=0;

%offset from the center of rotation
blade.offset=0; 

%offset between the blades
blade.offsetangle=0; % angle from end to end of blades [degrees]

%Compute Boundary Layer parameters with Xfoil
blade.BL = 0; %if 1 compute the values

%% Constants
blade.rho=1.20615;
blade.c0=342.943;
blade.nu=1.50142e-5;

%% Operating conditions
%Bruce Experiment and PowerFlow simulation running
%tip speed ratio of 4.
blade.speed = 21.38; %rotational speed [rad/s]
blade.meanflow = 4.01; %inflow speed [m/s]
blade.lt = 0.0075; % Lt.turbulence length scale [m]. %0.0075 %0.075 %0.75
blade.intensity = 0.01; %It.turbulent intensity [%] %0.01 %0.1 %0.7

%% Observer
% Activate the directivity
blade.dir=1; %If it is equal to 0 the directivity is off.

if mic == 0
    blade.observer= [4 0 0]; %single microphone
else
    blade.observer = mic(ind,:); %multiple microphones
end
%% Discretisation

%PitchVAWT rotates at 21.38 rad/s. It take 0.29 s to make 1 revolution. It
%corresponds to 9.9417e5 timesteps
%(1 timestep = 2.917e-7, for PowerFLOW simulation)

blade.sampling = 10; %percent data sampled number of time steps
blade.sources = 5; %number of noise sources along span (can be vector)
% blade.ts = 500; %number of timesteps in one revolution (to match CFD)
blade.ts = 360; %number of timesteps in one revolution (to match CFD)


%% Output

%Still need to decide what you want at the end.

file.plot_dir=0; %gives directivity (activates multi listeners(i.e. multiple microphones))
file.plot_result=1; %gives SPL vs frequency
blade.plot.delta=1; %gives bl params versus azimuth. (delta boundary layer thickness [m] and delta_star boundary layer displacement thickness [m]).
blade.plot.turb=0; %gives Lt,u',It vs. azi cant be on when bl is on (inflow conds). Lt is the freestream longitudinal integral length scale at the blade inlet [m], It is the freestream turbulent intensity at the blade inlet [%]
                   % u' is the turbulent velocity [m/s]
blade.plot.contourPlot=0; % plot 3D localisation
blade.plot.spectrum=1; %plot spectrum, dont put on with delta. plot azimuthal localisation


%% File Object
% - changes depending on initial data
%This tells the code
%which column of data represents which variable
file.column.x=2; %x-coordinate
file.column.y=3; %y-coordinate
file.column.xv_in=3; %bl data
file.column.yv_in=4;% bl data
file.column.k=6; %turbulent kinetic energy
file.column.int=7; %turb-intensity
file.column.epsilon=8; %turbulent dissipation rate
file.column.omega=9; %specific dissipation rate
file.column.xv=4; %bl data
file.column.yv=5;% bl data

%% Code Install Directory
file.dir1 = '..\noise_model';
end