function [blade noise] = noiseCalc_Xfoil(blade,count,noise,f,count2,probe,sources1)
% this function takes the blade object (with all data in it) as well as
% some additional data

% blade object containing geometry and options
% count - outer loop for timesteps
% count 2 -inner loop for blade discretisation (corresponds to ij, number
% of blade sources).
% noise - object containing all prediction data
% f - frequency spectrum in third octave bands
% observer - location of listener
% probe - data along inflow, suction and pressure probe
% sources 1 - loop for blade discretisation

    
%find attenuation, directivity
%remember that blade.dir == 0 means that the directivity is off. Then the
%directivity functions are equal to 1.
if blade.dir==0
    blade.directivityL=1;
    blade.directivityH=1;
    blade.directivityL_TI=1;
    blae.re=1;
else
    blade=attenuation(blade,count2,f);
end

%  figure(42432)
%  hold on
%  scatter(blade.currentangle,blade.directivityH,'k')
%  scatter(blade.currentangle,blade.directivityL,'g','filled')
% scatter(blade.currentangle,blade.directivityL_TI,'r')




%% TBL noise [BMP]
i = 1;
for j = 1:length(f)
% noise.SPL.tbl_temp(i)=TBLnoise_BPM_Xfoil(blade.aoa,blade.ddiv,blade.chord,blade.W,f(j),blade.directivityH,blade.directivityL,blade.re,probe.pressure.delta_star(count),probe.suction.delta_star(count));
noise.SPL.tbl_temp(i)=TBLnoise_BPM_Xfoil(blade.aoa,blade.ddiv,blade.chord,blade.W,f(j),blade.directivityH,blade.directivityL,blade.re);
i= i+1;
end

noise.SPL.TBL(count2,:,count)=noise.SPL.tbl_temp;

%% LBL-VS noise [BPM]
i = 1;
for j = 1:length(f)
% noise.SPL.lbl_temp(i) = LBLnoise_BPM_Xfoil(blade.aoa,blade.ddiv,blade.chord,blade.W,f(j),blade.directivityH,blade.re,probe.pressure.delta(count));
noise.SPL.lbl_temp(i) = LBLnoise_BPM_Xfoil(blade.aoa,blade.ddiv,blade.chord,blade.W,f(j),blade.directivityH,blade.re);
i= i+1;
end
noise.SPL.LBL(count2,:,count)= noise.SPL.lbl_temp;

%% TE (bluntness noise [BPM]
i = 1;
for j = 1:length(f)
% noise.SPL.te_temp = TEnoise_BPM_Xfoil(blade.aoa,blade.ddiv,blade.chord,blade.W,f,blade.directivityH,blade.re,probe.pressure.delta_star(count),probe.suction.delta_star(count));
noise.SPL.te_temp(i) = TEnoise_BPM_Xfoil(blade.aoa,blade.ddiv,blade.chord,blade.W,f(j),blade.directivityH,blade.re);
i= i+1;
end

noise.SPL.TE(count2,:,count)= noise.SPL.te_temp;

%% Inflow noise [Paterson and Buck]
%Remember in this case the turbulence length scale used is the one at the
%inflow, corresponding to Lt1. I choose the value of Lt1 while Lt2 (used in
%TNO and iTNO) is computed!!!!

[noise] = inflowNoise(blade,count,noise.lt(count),noise.intensity,noise,f,count2);

    
%% TBL noise [TNO]
    %suction side modifier
    suction=0;
    [noise.SPL.tno_pre] = TNO(probe.pressure.tno.U1,probe.pressure.tno.x2,probe.pressure.tno.tke,2.*probe.pressure.tno.L2,f,blade.ddiv,blade.re,suction,blade.rho,blade.directivityH);
    suction=1;
    [noise.SPL.tno_suc] = TNO(probe.suction.tno.U1,probe.suction.tno.x2,probe.suction.tno.tke,2.*probe.suction.tno.L2,f,blade.ddiv,blade.re,suction,blade.rho,blade.directivityH);
    
    %% TBL noise [iTNO]
    %suction side modifier
    suction=0;
    [noise.SPL.itno_pre] = iTNO(probe.pressure.tno.U1,probe.pressure.tno.x2,probe.pressure.tno.tke,2*probe.pressure.tno.L2,f,blade.ddiv,blade.re,suction,blade.rho,blade.directivityH,probe.pressure.tno.u22);
    suction=1;
    [noise.SPL.itno_suc] = iTNO(probe.suction.tno.U1,probe.suction.tno.x2,probe.suction.tno.tke,2*probe.suction.tno.L2,f,blade.ddiv,blade.re,suction,blade.rho,blade.directivityH,probe.suction.tno.u22);

% take TNO results and add to running total
noise.SPL.tno(count2,:,count)=addDB([noise.SPL.tno_pre; noise.SPL.tno_suc]);
noise.SPL.tno_temp=noise.SPL.tno(count2,:,count);
noise.SPL.tno_power(count2,:,count)=noise.SPL.tno(count2,:,count) - 10*log10(1/(4*pi*blade.re.^2));
noise.SPL.itno(count2,:,count)=addDB([noise.SPL.itno_pre; noise.SPL.itno_suc]);
noise.SPL.itno_temp=noise.SPL.itno(count2,:,count);
noise.SPL.itno_power(count2,:,count)=noise.SPL.itno(count2,:,count) - 10*log10(1/(4*pi*blade.re.^2));

%% sum noise
%find total noise for ts (1x XYZ coord)
%X is so specify source strength
noise.SPL.total_TBLX((count-1)*sources1+count2)= addDB(noise.SPL.tbl_temp);
noise.SPL.total_LBLX((count-1)*sources1+count2)= addDB(noise.SPL.lbl_temp);
noise.SPL.total_TEX((count-1)*sources1+count2)= addDB(noise.SPL.te_temp);
noise.SPL.total_inflowX((count-1)*sources1+count2)= addDB(noise.SPL.inflow_temp);
noise.SPL.total_amietX((count-1)*sources1+count2)= addDB(noise.SPL.amiet_temp);
noise.SPL.total_buckX((count-1)*sources1+count2)=addDB(noise.SPL.buck_temp);
noise.SPL.total_tnoX((count-1)*sources1+count2)= addDB(noise.SPL.tno_temp);
noise.SPL.total_itnoX((count-1)*sources1+count2)= addDB(noise.SPL.itno_temp);


end