% This script is used for making polar plots of the OSPL versus the azimuth
% angles. Figure 2.14 of the dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Extract high-fidelity results
%Medium simulation
load ../data/OSPL_medium.mat
%Fine simulation
load ../data/OSPL_fine.mat
%% OSPL - high-fidelity
theta_h_fine = deg2rad(theta_h_fine);
theta_v_fine = deg2rad(theta_v_fine);
theta_h_medium = deg2rad(theta_h_medium);
theta_v_medium = deg2rad(theta_v_medium);
%Add missing values
OSPL_v_fine(36,:) = OSPL_v_fine(1,:);
OSPL_v_medium(36,:) = OSPL_v_medium(1,:);
%% Plot
cd('../plot')
%In this case I cannot put just one hold on because matlab does not allow
%it for polarplot.
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
p1 = polarplot(theta_v_medium(1:14),OSPL_v_medium(1:14),'-o','Color',mycolor.black,'LineWidth',4);
hold on
p1 = polarplot(theta_v_medium(23:36,:),OSPL_v_medium(23:36,:),'-o','Color',mycolor.black,'LineWidth',4);
hold on;
p3 = polarplot(theta_v_fine(1:14),OSPL_v_fine(1:14),'-o','Color',mycolor.cyan_thesis,'LineWidth',2);
hold on
p3 = polarplot(theta_v_fine(23:36),OSPL_v_fine(23:36),'-o','Color',mycolor.cyan_thesis,'LineWidth',2);
ax = gca;
rruler = ax.RAxis;
rruler.Label.String = 'OASPL [dB]';
rruler.Label.Interpreter = 'latex';
truler = ax.ThetaAxis;
truler.Label.String = '$\phi$ [$^\circ$]';
truler.Label.Interpreter = 'latex';
thetaticks(0:45:360);
ax.ThetaZeroLocation = 'top';
rlim([0 70]);
rticks(0:15:75);
lg = legend([p1 p3],'LB-VLES medium','LB-VLES fine');
set(lg,'Interpreter','latex','Location','northwest outside');
set(gca,'TickLabelInterpreter','latex','FontSize',32,'FontWeight','bold');
exportgraphics(hfig,'OSPL_FWH_p_v_finemedium.pdf')
exportgraphics(hfig,'OSPL_FWH_p_v_finemedium.eps')
saveas(hfig,'OSPL_FWH_p_v_finemedium','fig');

hfig = figure(2);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
polarplot(theta_h_medium,OSPL_h_medium,'-o','Color',mycolor.black,'LineWidth',4);
hold on
polarplot(theta_h_fine,OSPL_h_fine,'-o','Color',mycolor.cyan_thesis,'LineWidth',2);
ax = gca;
rruler = ax.RAxis;
rruler.Label.String = 'OASPL [dB]';
rruler.Label.Interpreter = 'latex';
truler = ax.ThetaAxis;
truler.Label.String = '$\theta$ [$^\circ$]';
truler.Label.Interpreter = 'latex';
thetaticks(0:45:360);
ax.ThetaZeroLocation = 'top';
rlim([0 75]);
rticks(0:15:75);
lg = legend('LB-VLES medium','LB-VLES fine');
set(lg,'Interpreter','latex','Location','northwest outside');
set(gca,'TickLabelInterpreter','latex','FontSize',32,'FontWeight','bold');
exportgraphics(hfig,'OSPL_FWH_p_h_finemedium.pdf')
exportgraphics(hfig,'OSPL_FWH_p_h_finemedium.eps')
saveas(hfig,'OSPL_FWH_p_h_finemedium','fig');