%In this script the results (OSPL) from the low fidelity model 
% are plotted for vertical and horizontal microphone configurations and
% compared with the high-fidelity results.
%Figure 2.17 of the Dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data
%Low-fidelity - AC_DELPHINE_N7.
load ../data/OSPL_LF_h_AC_N7.mat
load ../data/OSPL_LF_v_AC_N7.mat
%High-fidelity
load ../data/OSPL_fine.mat
%% OSPL - high-fidelity
%Important! For OSPL_plots we need the azimuthal angle in radians and not
%in degree!!! In addition, I need row vectors not columns!
theta_h_fine = deg2rad(theta_h_fine);
theta_v_fine = deg2rad(theta_v_fine);
%Add missing values
OSPL_v_fine(36,:) = OSPL_v_fine(1,:);
%% Plot
%In this case I cannot put just one hold on because matlab does not allow
%it for polarplot.
cd('../plot')
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
p1 = polarplot(theta_v_fine(1:14),OSPL_v_fine(1:14),'-o','Color',mycolor.black,'LineWidth',4);
hold on
p1 = polarplot(theta_v_fine(23:36,:),OSPL_v_fine(23:36,:),'-o','Color',mycolor.black,'LineWidth',4);
hold on;
% p2 = polarplot(theta_perm_v_BPF_20BPF(1:14),OSPL_LF_v_AC_DELPHINE_N0p01.OSPL(1:14),'-o','Color',mycolor.orange,'LineWidth',3);
% hold on
% p2 = polarplot(theta_perm_v_BPF_20BPF(23:36),OSPL_LF_v_AC_DELPHINE_N0p01.OSPL(23:36),'-o','Color',mycolor.orange,'LineWidth',3);
% hold on
p3 = polarplot(theta_v_fine(1:14),OSPL_LF_v_AC_N7.OSPL(1:14),'-o','Color',mycolor.cyan_thesis,'LineWidth',3);
hold on
p3 = polarplot(theta_v_fine(23:36),OSPL_LF_v_AC_N7.OSPL(23:36),'-o','Color',mycolor.cyan_thesis,'LineWidth',3);
ax = gca;
rruler = ax.RAxis;
rruler.Label.String = 'OASPL [dB]';
rruler.Label.Interpreter = 'latex';
truler = ax.ThetaAxis;
truler.Label.String = '$\phi$ [$^\circ$]';
truler.Label.Interpreter = 'latex';
thetaticks(0:45:360);
ax.ThetaZeroLocation = 'top';
rlim([0 70]);
rticks(0:15:75);
lg = legend([p1 p3],'LB-VLES FWH perm','Noise model with AC $Ncrit$ = 7');
set(lg,'Interpreter','latex','Location','northwest outside');
set(gca,'TickLabelInterpreter','latex','FontSize',32,'FontWeight','bold');
exportgraphics(hfig,'OSPL_AC_DELPHINE_N7_FWH_p_v_BPF_20BPF_V2.pdf')
exportgraphics(hfig,'OSPL_AC_DELPHINE_N7_FWH_p_v_BPF_20BPF_V2.eps')
saveas(hfig,'OSPL_AC_DELPHINE_N7_FWH_p_v_BPF_20BPF_V2','fig');

hfig = figure(2);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
polarplot(theta_h_fine,OSPL_h_fine,'-o','Color',mycolor.black,'LineWidth',4);
hold on
polarplot(theta_h_fine,OSPL_LF_h_AC_N7.OSPL,'-o','Color',mycolor.cyan_thesis,'LineWidth',3);
ax = gca;
rruler = ax.RAxis;
rruler.Label.String = 'OASPL [dB]';
rruler.Label.Interpreter = 'latex';
truler = ax.ThetaAxis;
truler.Label.String = '$\theta$ [$^\circ$]';
truler.Label.Interpreter = 'latex';
thetaticks(0:45:360);
ax.ThetaZeroLocation = 'top';
rlim([0 75]);
rticks(0:15:75);
lg = legend('LB-VLES FWH perm','Noise model with AC $Ncrit$ = 7');
set(lg,'Interpreter','latex','Location','northwest outside');
set(gca,'TickLabelInterpreter','latex','FontSize',32,'FontWeight','bold');
exportgraphics(hfig,'OSPL_AC_DELPHINE_N7_FWH_p_h_BPF_20BPF_V2.pdf')
exportgraphics(hfig,'OSPL_AC_DELPHINE_N7_FWH_p_h_BPF_20BPF_V2.eps')
saveas(hfig,'OSPL_AC_DELPHINE_N7_FWH_p_h_BPF_20BPF_V2','fig');

