%This code is used to compare the FWH perm for two different resolutions of
%the high-fidelity simulation: medium and fine. The following plot is
%generated: PSDs. The PSD plot will be inserted in the Convergence
%chapter. Figure 2.8 of the dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data
%Medium resolution
load ../data/PSD_medium.mat
%Fine resolution
load ../data/PSD_fine.mat
%% Plot - PSD
cd('../plot')
h1 = figure(1);
set(h1,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
semilogx(f_psd_perm_medium_h_20band,PSD_perm_medium_h_20band(:,1),'Color',mycolor.black,'LineWidth',3)
semilogx(f_psd_perm_fine_h_20band,PSD_perm_fine_h_20band(:,1),':','Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 40])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('PSD [dB/Hz]','interpreter','latex','FontWeight','bold');
title('$\theta = 0^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES medium','LB-VLES fine');
set(lg,'Interpreter','latex','Location','northeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
nexttile
hold on; grid on;
semilogx(f_psd_perm_medium_v_20band,PSD_perm_medium_v_20band(:,1),'Color',mycolor.black,'LineWidth',3)
semilogx(f_psd_perm_fine_v_20band,PSD_perm_fine_v_20band(:,1),':','Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 40])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('PSD [dB/Hz]','interpreter','latex','FontWeight','bold');
title('$\phi = 0^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES medium','LB-VLES fine');
set(lg,'Interpreter','latex','Location','northeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
exportgraphics(h1,'PSD_FWH_perm_m_f_0_h_v_20band_V2.pdf')
saveas(h1,'PSD_FWH_perm_m_f_0_h_v_20band_V2','fig')
