%This code is used to plot the different outputs from the low-fidelity
%model. Figures 2.15 and 2.16 of the dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data
%Low-fidelity - AC model Geometric data
load ../data/SPL_LF_h_GEOMETRIC.mat
load ../data/SPL_LF_v_GEOMETRIC.mat
%Low-fidelity - AC model Ncrit = 0.01
load ../data/SPL_LF_h_AC_N0p01.mat
load ../data/SPL_LF_v_AC_N0p01.mat
%Low-fidelity - AC model Ncrit = 7
load ../data/SPL_LF_h_AC_N7.mat
load ../data/SPL_LF_v_AC_N7.mat
%% Plot
%Horizontal mics - TBL-TE vs T-I noise
%Upwind - 90 degree
cd('../plot')
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
semilogx(SPL_LF_h_GEOMETRIC.f,SPL_LF_h_GEOMETRIC.SPL_TBL(:,10),'Color',mycolor.black,'LineWidth',4)
semilogx(SPL_LF_h_AC_N0p01.f,SPL_LF_h_AC_N0p01.SPL_TBL(:,10),':','Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TBL(:,10),'--','Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
yticks(5:10:45)
ylim([5 45])
% ax = gca;
% ax.GridAlpha = 0.50;
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('TBL-TE noise - $\theta$ = 90$^\circ$','Interpreter','latex')
lg = legend('Noise model with geometric relation','Noise model with AC $Ncrit$ = 0.01',...
    'Noise model with AC $Ncrit$ = 7');
set(lg,'Interpreter','latex','Orientation','Vertical','Location','southeast')
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log')
nexttile
hold on; grid on;
semilogx(SPL_LF_h_GEOMETRIC.f,SPL_LF_h_GEOMETRIC.SPL_TI(:,10),'Color',mycolor.black,'LineWidth',4)
semilogx(SPL_LF_h_AC_N0p01.f,SPL_LF_h_AC_N0p01.SPL_TI(:,10),':','Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TI(:,10),'--','Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
yticks(5:10:45)
ylim([5 45])
% ax = gca;
% ax.GridAlpha = 0.50;
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('T-I noise - $\theta$ = 90$^\circ$','Interpreter','latex')
lg = legend('Noise model with geometric relation','Noise model with AC $Ncrit$ = 0.01',...
    'Noise model with AC $Ncrit$ = 7');
set(lg,'Interpreter','latex','Orientation','Vertical','Location','southeast')
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log')
exportgraphics(hfig,'SPL_AC_DELPHINE_N0p01_N7_geo_h_90_TBL_TI_V2.pdf')
saveas(hfig,'SPL_AC_DELPHINE_N0p01_N7_geo_h_90_TBL_TI_V2','fig')

%% Horizontal mics - LBL - 90 and 270 degree
cd('../plot')
hfig = figure(2);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
semilogx(SPL_LF_h_GEOMETRIC.f,SPL_LF_h_GEOMETRIC.SPL_LBL(:,10),'Color',mycolor.black,'LineWidth',4)
semilogx(SPL_LF_h_AC_N0p01.f,SPL_LF_h_AC_N0p01.SPL_LBL(:,10),':','Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_LBL(:,10),'--','Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
% ax = gca;
% ax.GridAlpha = 0.50;
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('LBL-VS noise - $\theta$ = 90$^\circ$','Interpreter','latex')
lg = legend('Noise model with geometric relation','Noise model with AC $Ncrit$ = 0.01',...
    'Noise model with AC $Ncrit$ = 7');
set(lg,'Interpreter','latex','Orientation','Vertical','Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log')
nexttile
hold on; grid on;
semilogx(SPL_LF_h_GEOMETRIC.f,SPL_LF_h_GEOMETRIC.SPL_LBL(:,28),'Color',mycolor.black,'LineWidth',4)
semilogx(SPL_LF_h_AC_N0p01.f,SPL_LF_h_AC_DELPHINE_N0p01.SPL_LBL(:,28),':','Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_LBL(:,28),'--','Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
% ax = gca;
% ax.GridAlpha = 0.50;
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('LBL-VS noise - $\theta$ = 270$^\circ$','Interpreter','latex')
lg = legend('Noise model with geometric relation','Noise model with AC $Ncrit$ = 0.01',...
    'Noise model with AC $Ncrit$ = 7');
set(lg,'Interpreter','latex','Orientation','Vertical','Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
exportgraphics(hfig,'SPL_AC_DELPHINE_N0p01_N7_geo_h_90_270_LBL_V2.pdf')
saveas(hfig,'SPL_AC_DELPHINE_N0p01_N7_geo_h_90_270_LBL_V2','fig')
