% This code is used to compare the SPL results of the low-fidelity model
% and the high-fidelity. Figures 2.18, 2.19, 2.20 of this dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data
%Low-fidelity - AC model Ncrit = 7
load ../data/SPL_LF_h_AC_N7.mat
load ../data/SPL_LF_v_AC_N7.mat
%High-fidelity - Fine resolution
load ../data/SPL_fine.mat
%% 1) Comparison - Horizontal mics - SPL sources
%Horizontal mics - LBL-VLES TBL-TE vs T-I noise - theta = 50 and theta =
%90
cd('../plot')
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
semilogx(f_perm_fine_h,SPL_perm_fine_h(:,6),'Color',mycolor.black,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TBL(:,6),'Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TI(:,6),'Color',mycolor.red,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_LBL(:,6),'Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('$\theta = 50^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES - FWH perm','TBL-TE noise','T-I noise','LBL-VS noise');
set(lg,'Interpreter','latex','Orientation','Horizontal','NumColumns',2,'Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
nexttile
hold on; grid on;
semilogx(f_perm_fine_h,SPL_perm_fine_h(:,10),'Color',mycolor.black,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TBL(:,10),'Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TI(:,10),'Color',mycolor.red,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_LBL(:,10),'Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('$\theta = 90^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES - FWH perm','TBL-TE noise','T-I noise','LBL-VS noise');
set(lg,'Interpreter','latex','Orientation','Horizontal','NumColumns',2,'Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
exportgraphics(hfig,'SPL_AC_DELPHINE_N7_FWH_p_50_90_h_V2.pdf')
saveas(hfig,'SPL_AC_DELPHINE_N7_FWH_p_50_90_h_V2','fig')

%% Horizontal mics - LBL-VLES TBL-TE vs T-I noise - theta = 220 and theta = 270
cd('../plot')
hfig = figure(2);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
semilogx(f_perm_fine_h,SPL_perm_fine_h(:,23),'Color',mycolor.black,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TBL(:,23),'Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TI(:,23),'Color',mycolor.red,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_LBL(:,23),'Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('$\theta = 220^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES - FWH perm','TBL-TE noise','T-I noise','LBL-VS noise');
set(lg,'Interpreter','latex','Orientation','Horizontal','NumColumns',2,'Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
nexttile
hold on; grid on;
semilogx(f_perm_fine_h,SPL_perm_fine_h(:,28),'Color',mycolor.black,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TBL(:,28),'Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_TI(:,28),'Color',mycolor.red,'LineWidth',3)
semilogx(SPL_LF_h_AC_N7.f,SPL_LF_h_AC_N7.SPL_LBL(:,28),'Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('$\theta = 270^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES - FWH perm','TBL-TE noise','T-I noise','LBL-VS noise');
set(lg,'Interpreter','latex','Orientation','Horizontal','NumColumns',2,'Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
exportgraphics(hfig,'SPL_AC_DELPHINE_N7_FWH_p_220_270_h_V2.pdf')
saveas(hfig,'SPL_AC_DELPHINE_N7_FWH_p_220_270_h_V2','fig')

%% phi = 20 phi = 270
cd('../plot')
hfig = figure(3);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
semilogx(f_perm_fine_v,SPL_perm_fine_v(:,3),'Color',mycolor.black,'LineWidth',3)
semilogx(SPL_LF_v_AC_N7.f,SPL_LF_v_AC_N7.SPL_TBL(:,3),'Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_v_AC_N7.f,SPL_LF_v_AC_N7.SPL_TI(:,3),'Color',mycolor.red,'LineWidth',3)
semilogx(SPL_LF_v_AC_N7.f,SPL_LF_v_AC_N7.SPL_LBL(:,3),'Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('$\phi = 20^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES - FWH perm','TBL-TE noise','T-I noise','LBL-VS noise');
set(lg,'Interpreter','latex','Orientation','Horizontal','NumColumns',2,'Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
nexttile
hold on; grid on;
semilogx(SPL_LF_v_AC_N7,SPL_perm_fine_v(:,28),'Color',mycolor.black,'LineWidth',3)
semilogx(SPL_LF_v_AC_N7.f,SPL_LF_v_AC_N7.SPL_TBL(:,28),'Color',mycolor.grey,'LineWidth',3)
semilogx(SPL_LF_v_AC_N7.f,SPL_LF_v_AC_N7.SPL_TI(:,28),'Color',mycolor.red,'LineWidth',3)
semilogx(SPL_LF_v_AC_N7.f,SPL_LF_v_AC_N7.SPL_LBL(:,28),'Color',mycolor.cyan_thesis,'LineWidth',3)
xlim([20 3000])
ylim([-10 60])
xlabel('$f$ [Hz]','interpreter','latex','FontWeight','bold');
ylabel('SPL [dB]','interpreter','latex','FontWeight','bold');
title('$\phi = 270^{\circ}$','Interpreter','latex')
lg = legend('LB-VLES - FWH perm','TBL-TE noise','T-I noise','LBL-VS noise');
set(lg,'Interpreter','latex','Orientation','Horizontal','NumColumns',2,'Location','southeast');
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold','XScale','log');
exportgraphics(hfig,'SPL_AC_DELPHINE_N7_FWH_p_20_270_v_V2.pdf')
saveas(hfig,'SPL_AC_DELPHINE_N7_FWH_p_20_270_v_V2','fig')

