% This script is used for comparing the angle of attack and the velocity
% perceived by the blades determined with geometric relation and with the
% AC model (as well as the AC model fitted with experimental and high-
%fidelity data). Figure 2.14 of the dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data
%Geometric relation - output (equals for all the airfoil)
load ../data/GEOMETRIC.mat
%AC model with Delphine formulation Ncrit = 0.01
load ../data/AC_N0p01.mat
%AC model with Delphine formulation Ncrit = 7
load ../data/AC_N7.mat
%AC model with Delphine formulation Ncrit = 9
load ../data/AC_N9.mat
%AC model with high-fidelity data as input
load ../data/AC_hfdata.mat
%% Plot
cd('../plot')
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
tiledlayout(1,2,'TileSpacing','compact')
nexttile
hold on; grid on;
plot(GEOMETRIC.theta,GEOMETRIC.alpha,'-','Color',mycolor.black,'LineWidth',3)
plot(AC_N0p01.theta,AC_N0p01.alpha,'-','Color',mycolor.grey,'LineWidth',3)
plot(AC_N7.theta,AC_N7.alpha,'-','Color',mycolor.red,'LineWidth',3)
plot(AC_hfdata.theta,AC_hfdata.alpha,'--','Color',mycolor.cyan_thesis,'LineWidth',3)
xlabel('$\theta[^{\circ}]$','interpreter','latex','FontSize',26,'FontWeight','bold')
ylabel('$\alpha[^{\circ}]$','interpreter','latex','FontSize',26,'FontWeight','bold') 
xlim([0 360])
ylim([-15 15])
yticks([-15:5:15])
xticks(0:90:360)
% ax = gca;
% ax.GridAlpha = 0.50;
lg = legend('Geometric relation','AC $Ncrit$ = 0.01','AC $Ncrit$ =7',...
'AC $Ncrit$ = 7 with LB-VLES');
set(lg,'Interpreter','latex','FontSize',15);
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold');
nexttile
hold on; grid on;
plot(GEOMETRIC.theta,GEOMETRIC.Vrel,'-','Color',mycolor.black,'LineWidth',3)
plot(AC_N0p01.theta,AC_N0p01.Vrel,'-','Color',mycolor.grey,'LineWidth',3)
plot(AC_N7.theta,AC_N7.Vrel,'-','Color',mycolor.red,'LineWidth',3)
plot(AC_hfdata.theta,AC_hfdata.Vrel,'--','Color',mycolor.cyan_thesis,'LineWidth',3)
xlabel('$\theta[^{\circ}]$','interpreter','latex','FontSize',26,'FontWeight','bold')
ylabel('$V_{\textrm{rel}}$[m/s]','interpreter','latex','FontSize',26,'FontWeight','bold') 
xlim([0 360])
ylim([11 21])
yticks([11:1.5:21])
xticks(0:90:360)
% ax = gca;
% ax.GridAlpha = 0.50;
lg = legend('Geometric relation','AC $Ncrit$ = 0.01','AC $Ncrit$ =7', ...
    'AC $Ncrit$ = 7 with LB-VLES');
set(lg,'Interpreter','latex','FontSize',15);
set(gca,'TickLabelInterpreter','latex','FontSize',20,'FontWeight','bold');
exportgraphics(hfig,'Comparison_alpha_Vrel_geo_ACDelphine_AChfdata_V2.pdf')
saveas(hfig,'Comparison_alpha_Vrel_geo_ACDelphine_AChfdata_V2','fig')

