%This code is used to compare the forces from the high-fidelity simulation
%with the forces from the low-fidelity and from the experiment.
%Figure 2.13 of the dissertation.
clear all
close all
clc
%% Settings for plotting
load ../data/mycolor.mat
width = 39.6875;
height = width*0.4;
%% Load data files
%High-fidelity
load ../data/HIGHFIDELITY.mat
%AC model with Delphine formulation Ncrit = 0.01
load ../data/AC_N0p01.mat
%AC model with Delphine formulation Ncrit = 7
load ../data/AC_N7.mat
%Experiment 
load ../data/EXPERIMENT.mat
%% PitchVAWT input parameters
c = 0.075;                  %chord length [m]
R = 1.48/2;                 %radius [m]
%% Plot force, Fn, on blade 1 (effect of AC model)
%To plot standard deviation of the experimental data
cd('../plot')
hfig = figure(1);
set(hfig,'Units', 'centimeters', 'pos', [2.619375 2.619375 width height])
hold on; grid on;
p1 = plot(HIGHFIDELITY.theta+rad2deg(0.25*c/R),HIGHFIDELITY.Fn_blade1,'LineWidth',3,'Color',mycolor.black);
p2 = plot(AC_N0p01.theta-rad2deg(0.25*c/R), AC_N0p01.Fn_b1,'LineWidth',3,'Color',mycolor.grey);
p3 = plot(AC_N7.theta-rad2deg(0.25*c/R),AC_N7.Fn_b1,'LineWidth',3,'Color',mycolor.grey2);
p4 = errorbar(EXPERIMENT.theta-rad2deg(0.25*c/R),EXPERIMENT.Fn_clean_raw',EXPERIMENT.stdFn_clean_raw','.','MarkerSize',20,'Color',mycolor.cyan_thesis);
p5 = errorbar(EXPERIMENT.theta-rad2deg(0.25*c/R),EXPERIMENT.Fn_trip_raw',EXPERIMENT.stdFn_trip_raw','.','MarkerSize',20,'Color',mycolor.red);
xlabel('$\theta [^{\circ}]$','Interpreter','latex','FontWeight','bold')
ylabel('$F_n$ on blade 1 [N]','Interpreter','latex','FontWeight','bold')
ylim([-30 30])
yticks(-30:10:30)
xlim([0 360])
xticks(0:90:360)
lg = legend([p1,p2,p3,p4,p5],'LB-VLES','AC $Ncrit$ = 0.01','AC $Ncrit$ = 7',...
    'Experiment clean','Experiment trip');
set(lg,'Interpreter','latex','FontSize',20,'Orientation','Horizontal','NumColumns',1,'Position', ...
    [0.683456519898079 0.630555563502841 0.170099035657474 0.276666658719381]);
set(gca,'FontSize',28,'TickLabelInterpreter','latex','FontWeight','bold')
exportgraphics(hfig,'Fn_blade1_HF_EXP_points_AC_Delphine_N0p01_7_V2.pdf')
saveas(hfig,'Fn_blade1_HF_EXP_points_AC_Delphine_N0p01_7_V2','fig');

